[−][src]Crate ep_capstone
Re-exports
pub use arch::InsnGroup; |
pub use arch::InsnId; |
pub use arch::Reg; |
pub use arch::arm; |
pub use arch::arm64; |
pub use arch::evm; |
pub use arch::m680x; |
pub use arch::m68k; |
pub use arch::mips; |
pub use arch::mos65xx; |
pub use arch::ppc; |
pub use arch::sparc; |
pub use arch::sysz; |
pub use arch::tms320c64x; |
pub use arch::x86; |
pub use arch::xcore; |
Modules
| arch |
Structs
| Capstone | A capstone instance that can be used for disassembly. |
| CapstoneVersion | The API version of capstone. |
| Details | Extra details about an isntruction. |
| Insn | Information about a disassembled instruction. |
| InsnBuffer | A buffer of disassembled instructions. |
| InsnIter | Iterator that lazily disassembles a binary blob of machine code.
This is constructed using |
| Mode | Mode flags for configuring |
| RegsBuffer | A list of registers that are either read from or written to by an instruction. |
| RegsUsed |
Enums
| Arch | |
| ArchDetails | |
| Error | |
| SupportQuery | Support query that can be used along with |
| Syntax | Disassembling engine assembly syntax. |
Functions
| supports | Queries Capstone's capabilities. Use this to check if the current build of Capstone supports a certain architecture or if the feature set is reduced. |
| version | Returns the current version of the capstone API. |
Type Definitions
| SkipdataCallback |