Reg

Struct Reg 

pub struct Reg(/* private fields */);
A generic register that can be compared to any architecture specific register. This register may be equal to multiple registers from different architectures but not to multiple registers of the same architecture. This can also be converted to an architecture specific register for any architecture.

Implementations

Source

impl Reg

pub fn x86(self) -> Reg

Convert a generic register to an architecture specific register.